==> metadata-1.2.21-sources.jar: com/xforceplus/ultraman/oqsengine/plus/meta/pojo/dto/table/SystemColumn.java <==
package com.xforceplus.ultraman.oqsengine.plus.meta.pojo.dto.table;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/**
 * Created by justin.xu on 03/2023.
 *
 * @since 1.8
 */
public class SystemColumn {

    public static final String ID = "id";
    public static final String SYS_ENTITY_CLASS = "_sys_entityclass";
    public static final String SYS_VERSION = "_sys_ver";
    public static final String SYS_OPERATE_TIME = "_sys_operatetime";
    public static final String SYS_DELETED = "_sys_deleted";
    public static final String SYS_PROFILE = "_sys_profile";
    public static final String DYNAMIC_FIELD = "_sys_dynamic";

    public static final Set<String> SYSTEM_WORDS =
        new HashSet<String>(Arrays.asList(ID, SYS_ENTITY_CLASS, SYS_VERSION, SYS_OPERATE_TIME, SYS_DELETED, SYS_PROFILE,
            DYNAMIC_FIELD));

    private long id;

    private long entityClass;

    private long version;

    private long operateTime;

    private boolean deleted;

    private String profile;

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public long getEntityClass() {
        return entityClass;
    }

    public void setEntityClass(long entityClass) {
        this.entityClass = entityClass;
    }

    public long getVersion() {
        return version;
    }

    public void setVersion(long version) {
        this.version = version;
    }

    public long getOperateTime() {
        return operateTime;
    }

    public void setOperateTime(long operateTime) {
        this.operateTime = operateTime;
    }

    public boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(boolean deleted) {
        this.deleted = deleted;
    }

    public String getProfile() {
        return profile;
    }

    public void setProfile(String profile) {
        this.profile = profile;
    }
}

==> metadata-1.2.37-sources.jar: com/xforceplus/ultraman/oqsengine/plus/meta/pojo/dto/table/SystemColumn.java <==
package com.xforceplus.ultraman.oqsengine.plus.meta.pojo.dto.table;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/**
 * Created by justin.xu on 03/2023.
 *
 * @since 1.8
 */
public class SystemColumn {

    public static final String ID = "id";
    public static final String SYS_ENTITY_CLASS = "_sys_entityclass";
    public static final String SYS_VERSION = "_sys_ver";
    public static final String SYS_OPERATE_TIME = "_sys_operatetime";
    public static final String SYS_DELETED = "_sys_deleted";
    public static final String SYS_PROFILE = "_sys_profile";
    public static final String DYNAMIC_FIELD = "_sys_dynamic";

    public static final Set<String> SYSTEM_WORDS =
        new HashSet<String>(Arrays.asList(ID, SYS_ENTITY_CLASS, SYS_VERSION, SYS_OPERATE_TIME, SYS_DELETED, SYS_PROFILE,
            DYNAMIC_FIELD));
    
    public static final Set<String> INVISIBLE_SYSTEM_WORDS =
            new HashSet<String>(Arrays.asList(SYS_ENTITY_CLASS, SYS_VERSION, SYS_OPERATE_TIME, SYS_DELETED, SYS_PROFILE,
                    DYNAMIC_FIELD));

    private long id;

    private long entityClass;

    private long version;

    private long operateTime;

    private boolean deleted;

    private String profile;

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public long getEntityClass() {
        return entityClass;
    }

    public void setEntityClass(long entityClass) {
        this.entityClass = entityClass;
    }

    public long getVersion() {
        return version;
    }

    public void setVersion(long version) {
        this.version = version;
    }

    public long getOperateTime() {
        return operateTime;
    }

    public void setOperateTime(long operateTime) {
        this.operateTime = operateTime;
    }

    public boolean getDeleted() {
        return deleted;
    }

    public void setDeleted(boolean deleted) {
        this.deleted = deleted;
    }

    public String getProfile() {
        return profile;
    }

    public void setProfile(String profile) {
        this.profile = profile;
    }
}
